@@ -5,19 +5,27 @@
 # See LICENSE.md for the full license text.
 
 from ctypes import CDLL, get_errno
-from os import strerror
+from os import strerror, PathLike, fsencode
+from platform import machine
 
-from typing import Union
-from pathlib import PurePath
-
-PathLike = Union[str, PurePath]
+SYSCALL_ARCH_MAP = {
+    "x86_64": 316,
+    "armv7l": 382,
+    "aarch64": 276,
+    "i386": 353,
+}
 
 libc = CDLL("libc.so.6", use_errno=True)
 syscall_function = libc.syscall
-SYSCALL_RENAMEAT2 = 316
+ARCH = machine()
 SWAP_FLAGS = 2
 SWAP_AT_CWD = -100
 
+if ARCH not in SYSCALL_ARCH_MAP:
+    raise NotImplementedError(f"Unsupported architecture: {ARCH}")
+
+SYSCALL_RENAMEAT2 = SYSCALL_ARCH_MAP[ARCH]
+
 
 def swap(
         first: PathLike, second: PathLike,
@@ -32,8 +40,8 @@ def swap(
     """
     result = syscall_function(
         SYSCALL_RENAMEAT2,
-        first_dir_fd, str(first).encode(),
-        second_dir_fd, str(second).encode(),
+        first_dir_fd, fsencode(first),
+        second_dir_fd, fsencode(second),
         SWAP_FLAGS
     )
     if result != 0:
